<?php

namespace Drupal\entity_mesh\Commands;

use Drupal\Core\Logger\LoggerChannelFactoryInterface;
use Drupal\entity_mesh\Batches\GeneralBatch;
use Drush\Commands\DrushCommands;
use Drush\Log\DrushLoggerManager;

/**
 * A Drush commandfile.
 *
 * In addition to this file, you need a drush.services.yml
 * in root of your module, and a composer.json file that provides the name
 * of the services file to use.
 *
 * See these files for an example of injecting Drupal services:
 *   - http://cgit.drupalcode.org/devel/tree/src/Commands/DevelCommands.php
 *   - http://cgit.drupalcode.org/devel/tree/drush.services.yml
 */
class EntityMeshCommands extends DrushCommands {

  /**
   * Logger Factory.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $loggerFactory;

  /**
   * Constructs a new MyCustomDrushCommand object.
   *
   * @param \Drupal\Core\Logger\LoggerChannelFactoryInterface $logger_factory
   *   The logger channel factory.
   */
  public function __construct(LoggerChannelFactoryInterface $logger_factory) {
    // parent::__construct();
    $this->loggerFactory = $logger_factory;
  }

  /**
   * Generates Entity Mesh data.
   *
   * @param string $type
   *   Mesh type.
   *
   * @usage entity-mesh:generate node
   *   Generate node mesh only
   *
   * @command entity-mesh:generate
   * @aliases entity-mesh-gen
   */
  public function generate($type) {
    $logger = $this->logger();
    $types = ($type === 'all') ? ['node'] : [$type];
    $batch = GeneralBatch::generateBatch($types);
    batch_set($batch->toArray());
    drush_backend_batch_process();
    if ($logger instanceof DrushLoggerManager) {
      $logger->notice('Batch operations end.');
    }
  }

}
